<?php
	
//------------------------------------------------------------------------
// This script is a part of ABC Mail Manager
//
// Version: 2.5
// Homepage: www.zakkis.ca
// Copyright (c) 2002-2003 Zakkis Technology, Inc.
// All rights reserved.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
// FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
// REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
// OF THE POSSIBILITY OF SUCH DAMAGE.
//
//------------------------------------------------------------------------
	

class MailEntry {

	var $desc;
	var $email;
	var $mail_disabled;
	var $confirmed;
	var $password;

	function MailEntry( $desc, $email, $mail_disabled, $confirmed, $password )
	{
		$this->desc = $desc;
		$this->email = $email;
		$this->mail_disabled = $mail_disabled;
		$this->confirmed = $confirmed;
		$this->password = $password;
	}
	
	function AsLine()
	{
		return $this->desc . ':' . $this->email . ':' . $this->mail_disabled . ':' . $this->confirmed . ':' . $this->password;
	}
	
	function AsMailLine()
	{
		return sprintf("\"%s\" <%s>", $this->desc, $this->email );
	}
	
} // end of MailEntry

class MailList
{
	var $name_dat = '';
	var $mails;
	var $has_mails = false;

	//
	// Construct new mail list object.
	
	function MailList( $confirm = 0 ) {
		global $folders, $active_folder;
		
		$no = $folders->data[ $active_folder ];
		$this->name_dat = "data/list$no.dat";
		
		$this->Read( $confirm );
	}
	
	
	//
	// Reads addres slist from the file
	
	function Read( $confirm = 0 ) {
	
		$this->mails = array();
		
		if( !file_exists( $this->name_dat ) )
			return;
	
		$lines = file( $this->name_dat );

		foreach( $lines as $line )
		{
			list( $desc, $email, $mail_disabled, $confirmed, $password ) = explode( ":", trim( $line ) );
			
			if ( $confirm != 0 )
				if ( $confirmed != 1 )
					continue;
						
			$this->mails[ crc32($email) ] = new MailEntry( $desc, $email, $mail_disabled, $confirmed, $password );
			if( !$mail_disabled )
				$this->has_mails = true;
		}
	}
	
	//
	// Reads addres slist from the file
	
	function Write() {
	
		$fd = fopen( $this->name_dat, "wb" );
		
		if( !$fd )
			return false;
			
		foreach( $this->mails as $mail )
			fwrite( $fd, $mail->AsLine() . "\n" );
			
		fclose( $fd );
		
		return true;
	}
	
	function AddNew( $desc, $email, $mail_disabled, $confirmed, $password )
	{
		//
		// Unqoute string
		
		$desc = trimq( $desc );
		$email = trimq( $email );
		
		$this->mails[ crc32($email) ] = new MailEntry( $desc, $email, $mail_disabled, $confirmed, $password );
	}
	
	function HasDesc( $desc )
	{
		$desc = trimq( $desc );
	
		foreach( $this->mails as $mail )
			if( $mail->desc == $desc )
				return true;
		return false;
	}
	
	function HasEMail( $email )
	{
		$email = trimq( $email );

		foreach( $this->mails as $mail )
			if( $mail->email == $email )
				return true;
		return false;
	}
	
	function HasAddress( $desc, $email )
	{
		if( !isset( $this->mails[ crc32($email) ] ) )
			return false;
		if( $this->mails[ crc32($email) ]->desc != $desc )
			return false;
		return true;
	}
	
	var $map = array( 'name' => 'desc', 'address' => 'email' );
	
	function SortCallback( $a, $b )
	{
		global $_int_sort_field;
		$nm = $_int_sort_field;
    	return strcasecmp( $a->$nm, $b->$nm );
	}
	
	function Sort( $field )
	{
		global $_int_sort_field;
		$_int_sort_field = $this->map[ $field ];
		usort( $this->mails, array('MailList','SortCallback') );
	}

} // end of MailList

?>